Author: bernhard
Date: Tue Apr 19 16:15:59 2005
New Revision: 7885

Added:
   trunk/build_tools/pmc2c.pl
      - copied, changed from rev 7884, trunk/classes/pmc2c2.pl
Removed:
   trunk/classes/pmc2c.pl
   trunk/classes/pmc2c2.pl
Modified:
   trunk/CREDITS
   trunk/MANIFEST
   trunk/classes/default.pmc
   trunk/config/gen/makefiles/dynclasses_pl.in
   trunk/config/gen/makefiles/root.in
   trunk/docs/vtables.pod
   trunk/lib/Parrot/Pmc2c.pm
   trunk/lib/Parrot/Pmc2c/Library.pm
   trunk/lib/Parrot/Vtable.pm
Log:
Clean up classes/pmc2c.pl
Move classes/pmc2c2.pl to build_tools/pmc2c.pl
Thanks to Matt Diephouse.


Modified: trunk/CREDITS
==============================================================================
--- trunk/CREDITS       (original)
+++ trunk/CREDITS       Tue Apr 19 16:15:59 2005
@@ -136,7 +136,7 @@
 D: parrotbench ruby benchmarks
 
 N: Ilya Martynov
-D: Patch to let pmc2c2.pl run from any directory
+D: Patch to let pmc2c.pl run from any directory
 D: Minor documentation updates
 
 N: Ion Alexandru Morega
@@ -218,6 +218,7 @@
 
 N: Matt Diephouse
 D: Turn off buffering layer in forth.pasm
+D: Various patches for pmc2c.pl
 
 N: Matt Fowles
 D: Resizable*Array classes

Modified: trunk/MANIFEST
==============================================================================
--- trunk/MANIFEST      (original)
+++ trunk/MANIFEST      Tue Apr 19 16:15:59 2005
@@ -37,6 +37,7 @@
 build_tools/ops2pm.pl                             [devel]
 build_tools/parrot_config_c.pl                    []
 build_tools/pbc2c.pl                              [devel]
+build_tools/pmc2c.pl                              []
 build_tools/revision_c.pl                         [devel]
 build_tools/vtable_h.pl                           []
 charset/ascii.c                                          []
@@ -99,8 +100,6 @@
 classes/perlscalar.pmc                            []
 classes/perlstring.pmc                            []
 classes/perlundef.pmc                             []
-classes/pmc2c.pl                                  []
-classes/pmc2c2.pl                                 []
 classes/pmcarray.pmc                             []
 classes/pmc.num                                  []
 classes/pointer.pmc                               []

Copied: trunk/build_tools/pmc2c.pl (from rev 7884, trunk/classes/pmc2c2.pl)
==============================================================================
--- trunk/classes/default.pmc   (original)
+++ trunk/classes/default.pmc   Tue Apr 19 16:15:59 2005
@@ -11,7 +11,7 @@
 These are the vtable functions for the default PMC class.
 
 All methods which are not defined here get a default implementation
-generated from F<vtable.tbl> by F<classes/pmc2c2.pl>.
+generated from F<vtable.tbl> by F<build_tools/pmc2c.pl>.
 
 =head2 Functions
 

Modified: trunk/config/gen/makefiles/dynclasses_pl.in
==============================================================================
--- trunk/config/gen/makefiles/dynclasses_pl.in (original)
+++ trunk/config/gen/makefiles/dynclasses_pl.in Tue Apr 19 16:15:59 2005
@@ -47,7 +47,7 @@
 }
 
 # PMC2C Config
-our $PMC2C = "$PERL $PATHQUOTE" . 
q[${build_dir}${slash}classes${slash}pmc2c2.pl] . $PATHQUOTE;
+our $PMC2C = "$PERL $PATHQUOTE" . 
q[${build_dir}${slash}build_tools${slash}pmc2c.pl] . $PATHQUOTE;
 
 # Actual commands
 sub compile_cmd {

Modified: trunk/config/gen/makefiles/root.in
==============================================================================
--- trunk/config/gen/makefiles/root.in  (original)
+++ trunk/config/gen/makefiles/root.in  Tue Apr 19 16:15:59 2005
@@ -514,9 +514,9 @@
        $(PERL) build_tools/c2str.pl --all
 
 # classes PMC build utils and rules
-PMC2CD=$(PERL) classes/pmc2c2.pl --dump
-PMC2CC=$(PERL) classes/pmc2c2.pl --c --no-lines
-PMC2CV=$(PERL) classes/pmc2c2.pl --vt
+PMC2CD=$(PERL) build_tools/pmc2c.pl --dump
+PMC2CC=$(PERL) build_tools/pmc2c.pl --c --no-lines
+PMC2CV=$(PERL) build_tools/pmc2c.pl --vt
 
 .pmc.dump :
        $(PMC2CD) $<

Modified: trunk/docs/vtables.pod
==============================================================================
--- trunk/docs/vtables.pod      (original)
+++ trunk/docs/vtables.pod      Tue Apr 19 16:15:59 2005
@@ -86,8 +86,9 @@
     % perl -I../lib genclass.pl FoobyNumber > foobynumber.pmc
 
 This will produce a skeleton C file (to be preprocessed by the
-F<pmc2c2.pl> program) with stubs for all the methods you need to fill in.
-The function C<init> allows you to set up anything you need to set up.
+F<build_tools/pmc2c.pl> program) with stubs for all the methods you need
+to fill in. The function C<init> allows you to set up anything you need
+to set up.
 
 Now you'll have to do something a little different depending on whether
 you're writing a built-in class or an extension class. If you're writing
@@ -310,6 +311,6 @@
 
   pmclass PackedArray extends Array { ...
 
-See the POD documentation in F<classes/pmc2c2.pl> for a list of useful
-keywords that you may use in the .pmc file. (Run
-C<perldoc -F pmc2c2.pl> to view the POD.)
+See the POD documentation in F<build_tools/pmc2c.pl> for a list of
+useful keywords that you may use in the .pmc file. (Run
+C<perldoc -F pmc2c.pl> to view the POD.)

Modified: trunk/lib/Parrot/Pmc2c.pm
==============================================================================
--- trunk/lib/Parrot/Pmc2c.pm   (original)
+++ trunk/lib/Parrot/Pmc2c.pm   Tue Apr 19 16:15:59 2005
@@ -12,7 +12,7 @@
 =head1 DESCRIPTION
 
 C<Parrot::Pmc2c> (and the L<subclasses|/SUBCLASSES> defined in this
-file) is used by F<classes/pmc2c2.pl> to generate C code from PMC files.
+file) is used by F<build_tools/pmc2c.pl> to generate C code from PMC files.
 
 =head2 Functions
 

Modified: trunk/lib/Parrot/Pmc2c/Library.pm
==============================================================================
--- trunk/lib/Parrot/Pmc2c/Library.pm   (original)
+++ trunk/lib/Parrot/Pmc2c/Library.pm   Tue Apr 19 16:15:59 2005
@@ -168,7 +168,7 @@
 
 =over 4
 
-=item F<classes/pmc2c2.pl>
+=item F<build_tools/pmc2c.pl>
 
 =back
 

Modified: trunk/lib/Parrot/Vtable.pm
==============================================================================
--- trunk/lib/Parrot/Vtable.pm  (original)
+++ trunk/lib/Parrot/Vtable.pm  Tue Apr 19 16:15:59 2005
@@ -12,8 +12,8 @@
 =head1 DESCRIPTION
 
 C<Parrot::Vtable> provides a collection of functions for manipulating
-PMC vtables. It is used by F<build_tools/jit2h.pl>, F<build_tools/vtable_h.pl>,
-F<classes/genclass.pl>, F<classes/null.pl> and F<classes/pmc2c2.pl>.
+PMC vtables. It is used by F<build_tools/jit2h.pl>, F<build_tools/pmc2c.pl>,
+F<build_tools/vtable_h.pl>, F<classes/genclass.pl>, and F<classes/null.pl>.
 
 
 =head2 Functions
@@ -290,14 +290,14 @@
 
 =item F<build_tools/jit2h.pl>
 
+=item F<build_tools/pmc2c.pl>
+
 =item F<build_tools/vtable_h.pl>
 
 =item F<classes/genclass.pl>
 
 =item F<classes/null.pl>
 
-=item F<classes/pmc2c2.pl>
-
 =back
 
 1;

Reply via email to
--- trunk/classes/pmc2c2.pl     (original)
+++ trunk/build_tools/pmc2c.pl  Tue Apr 19 16:15:59 2005
@@ -4,30 +4,30 @@
 
 =head1 NAME
 
-classes/pmc2c2.pl - PMC compiler (Version 2)
+build_tools/pmc2c.pl - PMC compiler (Version 2)
 
 =head1 SYNOPSIS
 
 Create F<classes/foo.dump>:
 
-    % perl classes/pmc2c2.pl --dump classes/foo.pmc ...
+    % perl build_tools/pmc2c.pl --dump classes/foo.pmc ...
 
 Create F<vtable.dump>:
 
-    % perl classes/pmc2c2.pl --vtable
+    % perl build_tools/pmc2c.pl --vtable
 
 Print a class tree for the specified PMCs:
 
-    % perl classes/pmc2c2.pl --tree classes/*.pmc
+    % perl build_tools/pmc2c.pl --tree classes/*.pmc
 
 Create F<classes/foo.c> and C<pmc_foo.h> from F<classes/foo.dump>:
 
-    % perl classes/pmc2c2.pl -c classes/foo.pmc ...
+    % perl build_tools/pmc2c.pl -c classes/foo.pmc ...
 
 Create fooX.c and pmc_fooX.h from fooX.dump files, also create libfoo.c
 containing the initialization function for all fooX PMCs.
 
-    % perl classes/pmc2c2.pl --library libfoo -c \
+    % perl build_tools/pmc2c.pl --library libfoo -c \
            classes/foo1.pmc classes/foo2.pmc ...
 
 =head1 DESCRIPTION
@@ -71,7 +71,7 @@
 
 To see the internal data structures please run:
 
     % perl classes/pmc2c2.pl --c --deb --deb sarray.pmc | less
 
 =head2 Compiling PMCs
 
@@ -730,7 +730,7 @@
         "verbose+"      => \$opt{verbose},
         "library=s"     => \$opt{library},
     );
-    unshift @include, ".", "$FindBin::Bin/..", $FindBin::Bin;
+    unshift @include, ".", "$FindBin::Bin/..", "$FindBin::Bin/../classes/";
 
     dump_default()                  and exit if $default;
     dump_pmc([EMAIL PROTECTED], @ARGV)      and exit if $dump;
@@ -71,7 +71,7 @@
 To see the internal data structures please run:
 
-    % perl classes/pmc2c2.pl --c --deb --deb sarray.pmc | less
+    % perl build_tools/pmc2c.pl --c --deb --deb sarray.pmc | less
 
 =head2 Compiling PMCs

Modified: trunk/classes/default.pmc
==============================================================================